<?php

/**
 * Implementiert die Einstellung der Logging Parameter
 * @author Miguel Palmer <mp@beronet.com>
 */
class Logging {

	private		$m_attr;

	private		$post_attr,
			$post_checked = 0;

	private		$isRequestRejected = 0,
			$reasonRejected = array();
                
	/**
	 * Constructor
	 */
	function __construct($m, $get = array(), $post = array(), $session = array()) {
		// set main GET variable
		$this->m_attr = $m;

		// check POST variable
		if (isset($post['address']) || isset($post['port']) || isset($post['syslog_facility'])) {
			// clean
			unset($post['m'], $post['a'], $post['submit']);

			$list_post = array(	'address' 	  => 'hostname'	, 'port' 	  => 'int-range', 'loglevel_debug'  => 'int-range', 'loglevel_message'     => 'int-range',
						'logging_message' => 'bool'	, 'logging_debug' => 'bool'	, 'syslog_facility' => 'int-range', 'system-check-enabled' => 'bool'	 );

			$list_post_options = array( 	'port'			=> array('min' => 1 	, 'max' => 65535 ),
							'loglevel_debug'	=> array('min' => 0 	, 'max' => 9     ),
							'loglevel_message'	=> array('min' => 0 	, 'max' => 2     ),
							'syslog_facility'	=> array('min' => 16	, 'max' => 23    ));

			$this->post_checked = 1;
			$this->post_attr = Helper::sanitizePost($post, $list_post, $this->post_checked, $this->reasonRejected, $list_post_options);

			$this->isRequestRejected = !$this->post_checked;
		}
	}

	/**
	 * Funktion display erzeugt den Inhalt von der HTML-Seite
	 * @return string HTML code
	 */

	function display() {
		require_once ('./includes/isgwtelnet.php');

		$name = "LOGGING_TITLE_DIS";
		include('./includes/header.php');

		$general_table = $this->dynamic_table();
		// build page content
		$ret .= $general_table;
		return $ret;
	}

	/**
	 *@return string Die Adresse von dem Loging Server
	 */

	function address() {
		$ba = new beroAri();
		$logserver = $ba->get("logserver");
		$ret = explode(":", $logserver);
		return $ret[0];
	}

	/**
	 * @return string Syslog dropdown
	 */

	function syslog() {
		$ba = new beroAri();
		$option = $ba->get("syslog_facility");
		$sel = "<select name='syslog_facility' class='form-control input-sm'>";
		$j = 0;
		for ($i = 16; $i <= 23; $i++) {
			if ($option == $i)
				$sel .= '<option value=\'' . $i . '\' selected>' . $i . ' - local ' . $j++ . '</option>';
			else
				$sel .= '<option value=\'' . $i . '\'>' . $i . ' - local ' . $j++ . '</option>';
		}
		$sel .= "</select>";
		return $sel;
	}

	/**
	 * @param string $log Name für dropdown
	 * @return string Loglevel Dropdown
	 */

	function loglevel($log) {
		$ba = new beroAri();
		$loglevel = $ba->get($log);
		$ret .= "<select name='$log' class='form-control input-sm'>";
		($log == "loglevel_message") ? $j = 2 : $j = 9;
		for ($i = 0; $i <= $j; $i++) {
			($i == $loglevel) ? $selected = "selected" : $selected = "";
			$ret .= "<option value='$i' $selected>$i</option>";
		}
		$ret .= "</select>";
		return $ret;
	}

	/**
	 * @return int Das Port von dem Logserver
	 */

	function port() {
		$ba = new beroAri();
		$logserver = $ba->get("logserver");
		$ret = explode(":", $logserver);
		return $ret[1];
	}

	/**
	 * @param string Name für checkbox
	 * @return string Checkbox zum log aktivieren
	 */

	function active($log) {
		$ba = new beroAri();
		$active = $ba->get($log);
		$checked = ($active == "1") ?  "checked" : "";
		return "<input type='checkbox' name='$log' value='1' $checked>";
	}

	/**
	 * @param beroConf $bc
	 * @return string Checkbox enable system log
	 */

	function systemLog($bc) {
		$sysLog = $bc->get("root", "system-check-enabled");
		if ($sysLog == "1") {
			return "<input type='hidden' name='system-check-enabled' value='0'>"
			. "<input type='checkbox' name='system-check-enabled' value='1' checked>";
		} else {
			return "<input type='hidden' name='system-check-enabled' value='0'>"
			. "<input type='checkbox' name='system-check-enabled' value='1'>";
		}
	}

	/**
	 * Speichert die Änderung der Logging Einstellungen
	 * @param beroconf $bc
	 * @return string HTML code
	 */
	private function _save_logging($bc) {
		$ba = new beroAri();

		if (($this->post_attr['address'] != "") && ($this->post_attr['port'] != "")) {
			$isgw = new isgwtelnet();
			$isgw->isgw_login();
			$isgw->logserver($this->post_attr['address'], $this->post_attr['port']);
			$ba->set("logserver", sqlite_escape_string($this->post_attr['address'] . ":" . $this->post_attr['port']));
		}

		if ($this->post_attr['loglevel_debug'] != "") {
			$isgw = new isgwtelnet();
			$isgw->isgw_login();
			$isgw->loglevel($this->post_attr['loglevel_debug']);
			$ba->set("loglevel_debug", sqlite_escape_string($this->post_attr['loglevel_debug']));
		}
		if ($this->post_attr['loglevel_message'] != "") {
			$isgw = new isgwtelnet();
			$isgw->isgw_login();
			$isgw->loglevel_message($this->post_attr['loglevel_message']);
			$ba->set("loglevel_message", sqlite_escape_string($this->post_attr['loglevel_message']));
		}

		if ($this->post_attr['logging_message'] == "1") {
			$isgw = new isgwtelnet();
			$isgw->isgw_login();
			$isgw->logactive_message(1);
			$ba->set("logging_message", 1);
		} else {
			$isgw = new isgwtelnet();
			$isgw->isgw_login();
			$isgw->netlog(0);
			$isgw->logactive_message(0);
			$isgw->loglevel_message(0);
			$ba->set("logging_message", 0);
			$ba->set("loglevel_message", 0);
		}
		if ($this->post_attr['logging_debug'] == "1") {
			$isgw = new isgwtelnet();
			$isgw->isgw_login();
			$isgw->logactive(1);
			$ba->set("logging_debug", 1);
		} else {
			$isgw = new isgwtelnet();
			$isgw->isgw_login();
			$isgw->logactive(0);
			$isgw->loglevel(0);
			$ba->set("logging_debug", 0);
			$ba->set("loglevel_debug", 0);
		}
		if ($this->post_attr['logging_message'] == "1" || $this->post_attr['logging_debug'] == "1") {
			$isgw = new isgwtelnet();
			$isgw->isgw_login();
			$isgw->netlog(1);
			$ba->set("logging_active", 1);
		} else {
			$isgw = new isgwtelnet();
			$isgw->isgw_login();
			$isgw->netlog(0);
			$isgw->loglevel_message(0);
			$isgw->loglevel(0);
			$ba->set("logging_active", 0);
			$ba->set("loglevel_message", 0);
			$ba->set("loglevel_debug", 0);
		}

		if (isset($this->post_attr['syslog_facility']) || isset($this->post_attr['system-check-enabled'])) {
			//Nur wenn syslog facility verändert wurde, ist ein oranges activate erforderlich
			if ($ba->get('syslog_facility') != $this->post_attr['syslog_facility'] || $bc->get("root", 'system-check-enabled') != $this->post_attr['system-check-enabled']) {
				$table .= Helper::activate(2, true, $this->m_attr, ACTIVATE);
			}
			$ba->set("syslog_facility", sqlite_escape_string($this->post_attr['syslog_facility']));
			$bc->set("root", "system-check-enabled", sqlite_escape_string($this->post_attr['system-check-enabled']));
		} else {
			$ba->set("syslog_facility", "16");
			$table .= Helper::activate(2, true, $this->m_attr, ACTIVATE);
		}

		$table .= Helper::activate(1, true, $this->m_attr, ACTIVATE);
		return $table;
	}

	/**
	 * Generiert das Formular für die Logging Einstellungen
	 * @return string HTML Code
	 */

	function dynamic_table() {
		require_once('/usr/fallback/beroConf.php');
		require_once("./includes/lang.php");
		$bc = new beroConf('root');
		//Logging Änderungen speichern

		if ($this->post_checked) {
			$table .= $this->_save_logging($bc);
		} else if ($this->isRequestRejected) {
			$table .= Helper::displayErrorMessage($this->reasonRejected['request'], $this->reasonRejected['checkor'], $this->reasonRejected['key']);
		}

		ob_start();
		?>
		<form name='logging_form' id='logging-form' class="form-horizontal" action='' method='POST'>
			<input type=hidden name=m value='<? echo $m ?>'>
			<input type=hidden name=a value='save'>
			<br>
			<p class="text-center lead">
				<? echo LOGGING_TABLE_HEADER_DIS ?>
			</p>
			<div class='form-group' data-toggle='tooltip' title='<? echo GENERAL_ADDRESS; ?>'>
				<label for='address' class='col-sm-5 control-label'><? echo LOGGING_SERVER_DIS ?></label>
				<div class='col-sm-4'>
					<input type='text' class='form-control input-sm' name='address' value='<? echo $this->address() ?>'>
				</div>
			</div>
			<div class='form-group' data-toggle='tooltip' title='<? echo GENERAL_PORT; ?>'>
				<label for='port' class='col-sm-5 control-label'><? echo LOGGING_SERVER_PORT_DIS ?></label>
				<div class='col-sm-4'>
					<input type='text' class='form-control input-sm' id='port' name='port' value='<? echo $this->port() ?>'>
				</div>
			</div>
			<div class='form-group' data-toggle='tooltip' title='<? echo LOGGING_MESSAGE_ACTIVE; ?>'>
				<label for='logging_message' class='col-sm-5 control-label'><? echo LOGGING_MESSAGE_ACTIVE_DIS ?></label>
				<div class='col-sm-4'>
					<? echo $this->active('logging_message') ?>
				</div>
			</div>
			<div class='form-group' data-toggle='tooltip' title='<? echo LOGGING_MESSAGE_LOGLEVEL; ?>'>
				<label for='loglevel_message' class='col-sm-5 control-label'><? echo LOGGING_MESSAGE_LEVEL_DIS ?></label>
				<div class='col-sm-4'>
					<? echo $this->loglevel('loglevel_message') ?>
				</div>
			</div>
			<div class='form-group' data-toggle='tooltip' title='<? echo LOGGING_DEBUG_ACTIVE; ?>'>
				<label for='logging_debug' class='col-sm-5 control-label'><? echo LOGGING_DEBUG_ACTIVE_DIS ?></label>
				<div class='col-sm-4'>
					<? echo $this->active('logging_debug') ?>
				</div>
			</div>
			<div class='form-group' data-toggle='tooltip' title='<? echo LOGGING_DEBUG_LOGLEVEL; ?>'>
				<label for='loglevel_debug' class='col-sm-5 control-label'><? echo LOGGING_DEBUG_LEVEL_DIS ?></label>
				<div class='col-sm-4'>
					<? echo $this->loglevel('loglevel_debug') ?>
				</div>
			</div>
			<div class='form-group'>
				<label for='system-check-enabled' class='col-sm-5 control-label'><? echo LOGGING_SYSTEM_LOG_DIS ?></label>
				<div class='col-sm-4'>
					<? echo $this->systemLog($bc) ?>
				</div>
			</div>
			<div class='form-group'>
				<label for='syslog_facility' class='col-sm-5 control-label'><? echo LOGGING_SYSLOG_DIS ?></label>
				<div class='col-sm-4'>
					<? echo $this->syslog() ?>
				</div>
			</div>

			<br>
			<div class='text-center'>
				<input name='submit' type='submit' class='btn btn-default' value='<? echo BUTTON_SAVE ?>'>
			</div>
			<br>
		</form>
		<script type='text/javascript'>

			$("#logging-form").validate({
				rules: {
			             	address: {
				              checkHostname: true,
			             	},
					port: {
						digit: true,
						range: [1, 65535]
					}
               			}
                        });
		</script>
		<?php
		$table .= ob_get_clean();

		//Rückgabe: Erzeugte Tabelle mit den änderbaren Feldern von den Einstellungen von isgw.conf
		return $table;
	}

}
